@@ -257,13 +257,13 @@ async def on_message(message):
                                 if "Usage" not in subprocess.getoutput(r"C:\Users\knowl\Downloads\Youtube-Dl\youtube-dl.exe"):
                                     print("Please install YouTube-dl to play music.")
                                     return
-                            subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 'ytsearch:{message.content.strip(' ')[1]}'", shell=True)
+                            subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 'ytsearch:{message.content.split(' ')[1:]}'", shell=True)
                         if platform.system() != "Windows":
                             command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
                             if "Usage" in subprocess.getoutput("youtube-dl"):
                                 print("Please install Youtube-dl to continue")
                                 return
-                            subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 'ytsearch:{message.content.split(' ')[1]}'", shell=True)
+                            subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 \"ytsearch:{message.content.split(' ')[1:]}\"", shell=True)
 
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
